# homey - integration with the Homey device

The Athom [Homey](http://www.athom.com) is a device with a somewhat similar goal to Igor: connecting all sorts of IoT devices in the home (and external services as well).

Homey and Igor take different approaches, but offer ample opportunity for integration: both offer ReST interfaces and both have a plugin model that allows control of external devices.

At the moment the Igor homey plugin does one thing: it allows reading of RFID tags using the Homey RFID reader.

Further documentation is to be provided.